<?php
// Include database connection
include('db_connection.php');

// Fetch total bookings
$totalBookings = $conn->query("SELECT COUNT(*) AS total FROM bookings")->fetch_assoc()['total'] ?? 0;

// Fetch daily revenue
$dailyRevenue = $conn->query("SELECT SUM(amount) AS total FROM bookings WHERE DATE(booking_date) = CURDATE()")->fetch_assoc()['total'] ?? 0;

// Fetch active customers
$activeCustomers = $conn->query("SELECT COUNT(DISTINCT client_email) AS total FROM bookings WHERE status = 'Completed'")->fetch_assoc()['total'] ?? 0;

// Fetch total barbers/pedicurists
$totalStaff = $conn->query("SELECT COUNT(*) AS total FROM staff WHERE role IN ('Barber', 'Pedicurist')")->fetch_assoc()['total'] ?? 0;

// Fetch recent bookings
$recentBookings = $conn->query("SELECT booking_code, client_name, client_email, service_name, booking_date, status FROM bookings ORDER BY booking_date DESC LIMIT 5");
if (!$recentBookings) {
    die("Error fetching recent bookings: " . $conn->error);
}

// Fetch frequent customers
$frequentCustomers = $conn->query("SELECT client_email, COUNT(client_email) AS booking_count FROM bookings GROUP BY client_email ORDER BY booking_count DESC LIMIT 5");
if (!$frequentCustomers) {
    die("Error fetching frequent customers: " . $conn->error);
}

// Fetch all bookings for the calendar
$allBookings = $conn->query("SELECT id, client_name, service_name, booking_date, status FROM bookings");
if (!$allBookings) {
    die("Error fetching all bookings for calendar: " . $conn->error);
}

// Helper function for status colors
function getStatusColor($status) {
    switch ($status) {
        case 'Completed':
            return '#2ecc71'; // Green
        case 'Cancelled':
            return '#e74c3c'; // Red
        default:
            return '#3498db'; // Blue
    }
}
?>


<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <link rel="stylesheet" href="assets/style.css">
    <link href="https://cdn.jsdelivr.net/npm/fullcalendar@5.11.3/main.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/fullcalendar@5.11.3/main.min.js"></script>
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
            background: linear-gradient(135deg, #05202B, #57D3D3);
            color: #fff;
        }
        .sidebar {
            background: linear-gradient(135deg, #05202B, #57D3D3);
        }
        .main-content {
            padding: 20px;
        }
        .header {
            margin-bottom: 20px;
        }
        .dashboard-metrics {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
            gap: 20px;
            margin-bottom: 20px;
        }
        .metric-box {
            background: linear-gradient(135deg, #57D3D3, #A3FCD6);
            padding: 20px;
            border-radius: 10px;
            text-align: center;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2);
        }
        .metric-box h2 {
            margin: 0 0 10px;
            font-size: 24px;
        }
        .metric-box p {
            margin: 0;
            font-size: 18px;
            font-weight: bold;
        }
    </style>
</head>
<body>
    <div class="sidebar">
        <div class="sidebar-header">
            <span class="hamburger" onclick="toggleSidebar()">☰</span>
            <span class="sidebar-title">Admin Panel</span>
        </div>
        <ul>
            <li><a href="index.php" class="active"><span class="icon"><i class="fas fa-home"></i></span><span class="text">Dashboard</span></a></li>
            <li><a href="add_service.php"><span class="icon"><i class="fas fa-concierge-bell"></i></span><span class="text">Manage Services</span></a></li>
            <li><a href="manage_bookings.php"><span class="icon"><i class="fas fa-calendar-check"></i></span><span class="text">View Bookings</span></a></li>
            <li><a href="manage_categories.php"><span class="icon"><i class="fas fa-calendar-check"></i></span><span class="text">Add Category</span></a></li>
            <li><a href="manage_categories.php"><span class="icon"><i class="fas fa-calendar-check"></i></span><span class="text">Add Category</span></a></li>
            <li><a href="manage_customers.php"><span class="icon"><i class="fas fa-users"></i></span><span class="text">Customers</span></a></li>
            <li><a href="logout.php"><span class="icon"><i class="fas fa-sign-out-alt"></i></span><span class="text">Logout</span></a></li>
        </ul>
    </div>
    <div class="main-content">
        <div class="header">
            <h1>Welcome, Admin!</h1>
            <div class="welcome-msg">Total Bookings: <?= htmlspecialchars($totalBookings); ?></div>
        </div>
        <div class="dashboard-metrics">
            <div class="metric-box">
                <h2>Total Bookings</h2>
                <p><?= htmlspecialchars($totalBookings); ?></p>
            </div>
            <div class="metric-box">
                <h2>Daily Revenue</h2>
                <p>&#8358;<?= number_format($dailyRevenue, 2); ?></p>
            </div>
            <div class="metric-box">
                <h2>Active Customers</h2>
                <p><?= htmlspecialchars($activeCustomers); ?></p>
            </div>
            <div class="metric-box">
                <h2>Barbers/Pedicurists</h2>
                <p><?= htmlspecialchars($totalStaff); ?></p>
            </div>
        </div>
        <div class="card">
            <h2>Recent Bookings</h2>
            <div class="table-container">
                <table class="table">
                    <thead>
                        <tr>
                            <th>Booking Code</th>
                            <th>Name</th>
                            <th>Email</th>
                            <th>Service</th>
                            <th>Date</th>
                            <th>Status</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php while ($booking = $recentBookings->fetch_assoc()): ?>
                        <tr>
                            <td><?= htmlspecialchars($booking['booking_code']); ?></td>
                            <td><?= htmlspecialchars($booking['client_name']); ?></td>
                            <td><?= htmlspecialchars($booking['client_email']); ?></td>
                            <td><?= htmlspecialchars($booking['service_name']); ?></td>
                            <td><?= htmlspecialchars($booking['booking_date']); ?></td>
                            <td style="color: <?= getStatusColor($booking['status']); ?>;">
                                <?= htmlspecialchars($booking['status']); ?>
                            </td>
                        </tr>
                        <?php endwhile; ?>
                    </tbody>
                </table>
            </div>
        </div>
        <div class="card">
            <h2>Booking Calendar</h2>
            <div id="calendar"></div>
        </div>
    </div>

    <script>
        document.addEventListener('DOMContentLoaded', function () {
            var calendarEl = document.getElementById('calendar');

            var bookings = <?php
                $events = [];
                while ($row = $allBookings->fetch_assoc()) {
                    $events[] = [
                        'title' => htmlspecialchars($row['client_name']) . " - " . htmlspecialchars($row['service_name']),
                        'start' => htmlspecialchars($row['booking_date']),
                        'id' => htmlspecialchars($row['id']),
                        'status' => htmlspecialchars($row['status']),
                        'color' => getStatusColor($row['status'])
                    ];
                }
                echo json_encode($events);
            ?>;

            var calendar = new FullCalendar.Calendar(calendarEl, {
                initialView: 'dayGridMonth',
                headerToolbar: {
                    left: 'prev,next today',
                    center: 'title',
                    right: 'dayGridMonth,timeGridWeek,timeGridDay'
                },
                events: bookings,
                eventClick: function(info) {
                    alert('Booking ID: ' + info.event.id + '\nStatus: ' + info.event.extendedProps.status);
                }
            });

            calendar.render();
        });
    </script>
</body>
</html>
