<?php
session_start();

// Database connection details
$servername = "localhost";
$username = "ultracloudns_base";
$password = "ultracloudns_base";
$dbname = "ultracloudns_base";

// Create a new PDO connection
try {
    $pdo = new PDO("mysql:host=$servername;dbname=$dbname", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    echo "Connection failed: " . $e->getMessage();
    exit();
}

// Ensure POST data is available
$selectedServices = isset($_POST['selected_services']) ? json_decode($_POST['selected_services'], true) : [];
$selectedProfessionalId = isset($_POST['selected_professional']) ? $_POST['selected_professional'] : null;
$selectedDate = isset($_POST['selected_date']) ? $_POST['selected_date'] : null;
$selectedTime = isset($_POST['selected_time']) ? $_POST['selected_time'] : null;
$totalPrice = 0;

// Calculate total price
foreach ($selectedServices as $service) {
    $totalPrice += $service['price'];
}

// Code starters for booking codes
$codeStarters = ["WIDBK", "LUXBK", "WBOOK", "WINBK", "LXBOK", "WNXRY", "LRYBK", "WBKRY", "WLXRY", "BKWLX"];

// Generate random alphanumeric string
function generateRandomString($length = 5) {
    $characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789';
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[rand(0, strlen($characters) - 1)];
    }
    return $randomString;
}

// Generate a unique booking code
function generateBookingCode($codeStarters, $pdo) {
    do {
        $randomParts = [];
        $numCodeStarters = rand(1, 4); // 1–4 code starters in a code

        // Randomly pick code starters
        for ($i = 0; $i < $numCodeStarters; $i++) {
            $randomParts[] = $codeStarters[array_rand($codeStarters)];
        }

        // Add random alphanumeric parts
        $randomParts[] = generateRandomString();
        $randomParts[] = generateRandomString();

        // Shuffle the parts to randomize positions
        shuffle($randomParts);

        // Combine the parts into a booking code
        $bookingCode = implode('-', $randomParts);

        // Check uniqueness in the database
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM bookings WHERE booking_code = :booking_code");
        $stmt->bindParam(':booking_code', $bookingCode, PDO::PARAM_STR);
        $stmt->execute();
        $exists = $stmt->fetchColumn();
    } while ($exists > 0); // Repeat until a unique code is generated

    return $bookingCode;
}

// Generate the next order ID
function generateOrderId($pdo) {
    $stmt = $pdo->prepare("SELECT MAX(id) FROM bookings");
    $stmt->execute();
    $lastId = $stmt->fetchColumn();

    // Increment last ID and prefix with 'LKWIN-'
    return 'LKWIN-' . str_pad(($lastId + 1), 6, '0', STR_PAD_LEFT);
}

try {
    // Generate a unique order ID for this booking
    $orderId = generateOrderId($pdo);

    // Begin transaction
    $pdo->beginTransaction();

    // Prepare an array to store booking codes
    $bookingCodes = [];

    // Insert each selected service into the database with a unique booking code
    foreach ($selectedServices as $service) {
        $stmt = $pdo->prepare("INSERT INTO bookings (client_name, client_email, client_phone, service_id, amount, staff_id, booking_date, booking_code, order_id, status, service_name) 
                                VALUES (:client_name, :client_email, :client_phone, :service_id, :amount, :staff_id, :booking_date, :booking_code, :order_id, 'Pending', :service_name)");

        $clientName = $_POST['client_name'];
        $clientEmail = $_POST['client_email'];
        $clientPhone = $_POST['client_phone'];
        $serviceId = $service['id'];
        $amount = $service['price'];
        $staffId = $selectedProfessionalId;
        $bookingDate = $selectedDate . ' ' . $selectedTime;
        $serviceName = $service['name'];
        $bookingCode = generateBookingCode($codeStarters, $pdo); // Unique booking code for each service

        // Store booking codes in the array
        $bookingCodes[] = $bookingCode;

        $stmt->bindParam(':client_name', $clientName);
        $stmt->bindParam(':client_email', $clientEmail);
        $stmt->bindParam(':client_phone', $clientPhone);
        $stmt->bindParam(':service_id', $serviceId, PDO::PARAM_INT);
        $stmt->bindParam(':amount', $amount);
        $stmt->bindParam(':staff_id', $staffId, PDO::PARAM_INT);
        $stmt->bindParam(':booking_date', $bookingDate);
        $stmt->bindParam(':booking_code', $bookingCode);
        $stmt->bindParam(':order_id', $orderId);
        $stmt->bindParam(':service_name', $serviceName);

        $stmt->execute();
    }

    // Commit transaction
    $pdo->commit();

    // Save order ID and booking codes in session for use on the confirmation page
    $_SESSION['booking_data'] = [
        'order_id' => $orderId,
        'booking_codes' => $bookingCodes,
        'client_name' => $clientName,
        'client_email' => $clientEmail,
        'client_phone' => $clientPhone,
        'selected_date' => $selectedDate,
        'selected_time' => $selectedTime,
        'services' => $selectedServices
    ];

    // Redirect to confirmation page
    header("Location: confirmation.php");
    exit();
} catch (PDOException $e) {
    $pdo->rollBack();
    echo "Error: " . $e->getMessage();
    exit();
}
?>
