<?php
session_start();

// Debugging: Check if session data exists
if (!isset($_SESSION['booking_data'])) {
    echo "No booking data found. Please try again.";
    exit();
}

// Retrieve booking data from the session
$bookingData = $_SESSION['booking_data'];
if (empty($bookingData['client_name']) || empty($bookingData['client_email'])) {
    echo "Client details are missing. Please try again.";
    exit();
}

$bookingCodes = $bookingData['booking_codes'] ?? [];
$clientName = htmlspecialchars($bookingData['client_name']);
$clientEmail = htmlspecialchars($bookingData['client_email']);
$clientPhone = htmlspecialchars($bookingData['client_phone'] ?? '');
$selectedDate = htmlspecialchars($bookingData['selected_date']);
$selectedTime = htmlspecialchars($bookingData['selected_time']);
$selectedServices = $bookingData['services'] ?? [];
$orderId = htmlspecialchars($bookingData['order_id']);

// Optionally, clear the session data for security
unset($_SESSION['booking_data']);

// Include the email sending script
require 'send_mail.php';

// Prepare services list for email content
$servicesList = '';
foreach ($selectedServices as $service) {
    $servicesList .= htmlspecialchars($service['name']) . " - ₦" . number_format($service['price'], 2) . "<br>";
}

// Send email to client
sendClientEmail(
    $clientName,
    $clientEmail,
    implode(", ", $bookingCodes), // Combine booking codes into a single string
    $servicesList,
    $selectedDate,
    $selectedTime,
    $orderId
);

// Send email to admin
sendAdminEmail(
    $clientName,
    $clientEmail,
    implode(", ", $bookingCodes),
    $servicesList,
    $selectedDate,
    $selectedTime,
    $orderId
);

// Display a confirmation message to the user
echo "<h1>Booking Confirmed</h1>";
echo "<p>Thank you, $clientName! Your booking has been confirmed.</p>";
echo "<p>Order ID: $orderId</p>";
echo "<p>An email has been sent to $clientEmail with the details.</p>";
?>
