<?php
// Include the database connection file
require 'includes/db_connection.php';

// Retrieve the selected services data from POST request
$selectedServices = [];
if (isset($_POST['selected_services'])) {
    $selectedServices = json_decode($_POST['selected_services'], true);
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Select Professionals & Schedule</title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/flatpickr/dist/flatpickr.min.css">
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
            background-color: #F9F9F9;
            font-size: 50%; /* Match font size to service.php */
            display: flex;
            flex-direction: column;
            min-height: 100vh;
        }
        .header {
            position: fixed;
            top: 0;
            width: 100%;
            background-color: #F9F9F9;
            padding: 20px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            z-index: 10;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        .header h2 {
            font-size: 0.7em;
            color: #05202B;
        }
        .header img {
            height: 50px;
            margin-right: 30px;
            /* Adjusted height for logo */
        }
        .container {
            flex: 1;
            max-width: 1200px;
            margin: auto;
            padding: 80px 20px 20px;
            overflow-y: auto;
            padding-bottom: 60px;
        }
        h2 {
            font-size: 2.2em; /* Match font size */
            color: #05202B;
            margin-bottom: 10px;
        }
        .professionals, .time-list {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            margin-bottom: 80px;
        }
        .professional-card, .time-slot {
            padding: 15px;
            border: 1px solid #ddd;
            border-radius: 8px;
            cursor: pointer;
            text-align: center;
            flex: 1 1 calc(25% - 20px);
            background-color: #FFF;
            transition: all 0.3s ease;
        }
        .professional-card:hover, .professional-card.selected,
        .time-slot:hover, .time-slot.selected {
            background: linear-gradient(to right, #57D3D3, #A3FCD6);
            color: #FFF;
        }
        .footer-summary {
            position: fixed;
            bottom: 0;
            width: 100%;
            background-color: #F1F1F1;
            padding: 20px;
            display: flex;
            justify-content: space-between;
            align-items: center;
            border-top: 1px solid #ddd;
            z-index: 10;
        }
        .continue-btn {
            padding: 15px 30px;
            background-color: #05202B;
            color: #FFF;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-size: 1.2em;
            transition: all 0.3s ease;
            margin-right: 30px;
        }
        .continue-btn:hover {
            background-color: #57D3D3;
        }
       /* Preloader Styles */
        .preloader {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: white;
            display: flex;
            justify-content: center;
            align-items: center;
            z-index: 10000;
        }

        .preloader img {
            width: 120px;
            height: 120px;
            animation: rotate 1.5s linear infinite;
        }

        @keyframes rotate {
            from {
                transform: rotate(0deg);
            }
            to {
                transform: rotate(360deg);
            }
        }
    </style>
    <script src="https://cdn.jsdelivr.net/npm/flatpickr"></script>
</head>
<body>
    <div class="preloader">
        <img src="assets/images/Widonslogo1.png" alt="Loading...">
    </div>
    <div class="header">
        <h1>Select Professionals & Schedule</h1>
        <img src="assets/images/Widonslogo1.png" alt="Logo">
    </div>

    <div class="container">
        <!-- Professionals Section -->
        <h2>Select a Professional</h2>
        <div class="professionals" id="professional-list">
            <?php
            $query = "SELECT id, full_name, role FROM staff WHERE role IS NOT NULL";
            $result = mysqli_query($conn, $query);

            // Add "Any Professional" option
            echo '<div class="professional-card" onclick="selectProfessional(null, this)">Any Professional</div>';

            while ($row = mysqli_fetch_assoc($result)) {
                echo "<div class='professional-card' onclick='selectProfessional(" . $row['id'] . ", this)'>"
                    . htmlspecialchars($row['full_name']) . "<br><small>" . htmlspecialchars($row['role']) . "</small></div>";
            }
            ?>
        </div>

        <!-- Calendar Section -->
        <h2>Select a Date</h2>
        <div id="calendar"></div>

        <!-- Time Slots -->
        <h2>Select a Time</h2>
        <div class="time-list" id="time-list"></div>
    </div>

    <!-- Footer Summary -->
    <div class="footer-summary">
        <div id="summary-details">
            <p>Professional: <span id="selected-professional">None</span></p>
            <p>Date: <span id="selected-date">None</span></p>
            <p>Time: <span id="selected-time">None</span></p>
            <p>Selected Services:</p>
            <ul>
                <?php
                $totalPrice = 0;
                foreach ($selectedServices as $service) {
                    echo "<li>" . htmlspecialchars($service['name']) . " - ₦" . number_format($service['price'], 2) . "</li>";
                    $totalPrice += $service['price'];
                }
                ?>
            </ul>
            <p>Total: <strong>₦<?php echo number_format($totalPrice, 2); ?></strong></p>
        </div>
        <form action="summary.php" method="POST" id="summary-form">
            <input type="hidden" name="selected_professional" id="input-professional">
            <input type="hidden" name="selected_date" id="input-date">
            <input type="hidden" name="selected_time" id="input-time">
            <input type="hidden" name="selected_services" value='<?php echo json_encode($selectedServices); ?>'>
            <button type="button" class="continue-btn" onclick="submitForm()">Next</button>
        </form>
    </div>
     <script>
        document.addEventListener("DOMContentLoaded", function () {
            const preloader = document.querySelector('.preloader');
            setTimeout(() => {
                preloader.style.display = 'none';
            }, 10000); // 10 seconds
        });
    </script>
    <script>
        let selectedProfessional = null;
        let selectedDate = null;
        let selectedTime = null;

        function selectProfessional(id, element) {
            document.querySelectorAll('.professional-card').forEach(card => card.classList.remove('selected'));
            element.classList.add('selected');
            selectedProfessional = id;
            document.getElementById('selected-professional').textContent = element.textContent.trim();
        }

        function selectTimeSlot(time, element) {
            document.querySelectorAll('.time-slot').forEach(slot => slot.classList.remove('selected'));
            element.classList.add('selected');
            selectedTime = time;
            document.getElementById('selected-time').textContent = time;
        }

        function initializeTimeSlots(selectedDate) {
            const timeList = document.getElementById('time-list');
            timeList.innerHTML = '';
            const startHour = 8;
            const endHour = 20;

            const now = new Date();
            const currentTime = now.getHours() * 60 + now.getMinutes();

            for (let hour = startHour; hour <= endHour; hour++) {
                for (let min = 0; min < 60; min += 30) {
                    const timeSlot = `${hour.toString().padStart(2, '0')}:${min.toString().padStart(2, '0')}`;
                    const slotTime = hour * 60 + min;
                    if (selectedDate.toDateString() === now.toDateString() && slotTime < currentTime) {
                        continue;
                    }

                    const slotDiv = document.createElement('div');
                    slotDiv.className = 'time-slot';
                    slotDiv.textContent = timeSlot;
                    slotDiv.onclick = () => selectTimeSlot(timeSlot, slotDiv);
                    timeList.appendChild(slotDiv);
                }
            }
        }

        function submitForm() {
            if (selectedProfessional !== null) {
                document.getElementById('input-professional').value = selectedProfessional;
            }
            if (selectedDate !== null) {
                document.getElementById('input-date').value = selectedDate.toISOString().split('T')[0];
            }
            if (selectedTime !== null) {
                document.getElementById('input-time').value = selectedTime;
            }
            document.getElementById('summary-form').submit();
        }

        flatpickr('#calendar', {
            inline: true,
            minDate: 'today',
            onChange: function(selectedDates) {
                selectedDate = selectedDates[0];
                document.getElementById('selected-date').textContent = selectedDate.toDateString();
                initializeTimeSlots(selectedDate);
            }
        });

        initializeTimeSlots(new Date());
    </script>
</body>
</html>
