<?php
// Start session to retrieve booking data
session_start();

// Database credentials
$servername = "localhost";
$username = "ultracloudns_base";
$password = "ultracloudns_base";
$dbname = "ultracloudns_base";

// Create a new database connection
try {
    $pdo = new PDO("mysql:host=$servername;dbname=$dbname", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    echo "Connection failed: " . $e->getMessage();
    exit();
}

// Ensure POST data is available
$selectedServices = isset($_POST['selected_services']) ? json_decode($_POST['selected_services'], true) : [];
$selectedProfessionalId = isset($_POST['selected_professional']) ? $_POST['selected_professional'] : null;
$selectedDate = isset($_POST['selected_date']) ? $_POST['selected_date'] : null;
$selectedTime = isset($_POST['selected_time']) ? $_POST['selected_time'] : null;
$totalPrice = 0;

// Calculate total price based on selected services
foreach ($selectedServices as $service) {
    $totalPrice += $service['price'];
}

// Fetch the professional's name using the staff ID
$selectedProfessionalName = '';
if ($selectedProfessionalId) {
    try {
        // Prepare the SQL query to fetch the professional's name
        $stmt = $pdo->prepare("SELECT full_name FROM staff WHERE id = :id");
        $stmt->bindParam(':id', $selectedProfessionalId, PDO::PARAM_INT);
        $stmt->execute();

        // Fetch the result
        $professional = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($professional) {
            $selectedProfessionalName = $professional['full_name'];
        }
    } catch (PDOException $e) {
        echo "Error: " . $e->getMessage();
    }
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Booking Summary</title>
    <link rel="stylesheet" href="styles.css">
</head>
<body>
    <div class="container">
        <h1>Booking Summary</h1>
        <p><strong>Professional:</strong> <?php echo htmlspecialchars($selectedProfessionalName); ?></p>
        <p><strong>Date:</strong> <?php echo htmlspecialchars($selectedDate); ?></p>
        <p><strong>Time:</strong> <?php echo htmlspecialchars($selectedTime); ?></p>
        <h3>Selected Services</h3>
        <ul>
            <?php
            foreach ($selectedServices as $service) {
                echo "<li>" . htmlspecialchars($service['name']) . " - ₦" . number_format($service['price'], 2) . "</li>";
            }
            ?>
        </ul>
        <p><strong>Total:</strong> ₦<?php echo number_format($totalPrice, 2); ?></p>

        <form action="bookinglogic.php" method="POST">
            <h3>Your Details</h3>
            <label for="client_name">Full Name:</label>
            <input type="text" name="client_name" id="client_name" required><br>

            <label for="client_email">Email:</label>
            <input type="email" name="client_email" id="client_email" required><br>

            <label for="client_phone">Phone Number:</label>
            <input type="text" name="client_phone" id="client_phone" required><br>

            <!-- Hidden fields to pass selected data -->
            <input type="hidden" name="selected_services" value='<?php echo json_encode($selectedServices); ?>'>
            <input type="hidden" name="selected_professional" value="<?php echo htmlspecialchars($selectedProfessionalId); ?>">
            <input type="hidden" name="selected_date" value="<?php echo htmlspecialchars($selectedDate); ?>">
            <input type="hidden" name="selected_time" value="<?php echo htmlspecialchars($selectedTime); ?>">

            <button type="submit">Confirm Booking</button>
        </form>
    </div>
</body>
</html>
